.. Copyright (C) 2025 @verzierf <francois.verzier@univ-grenoble-alpes.fr>

.. SPDX-License-Identifier: LGPL-3.0-or-later

.. _user_guide:

==========
User Guide
==========

This guide will help you get started with mater-data-providing, from installation to creating your first datasets.

.. toctree::
   :maxdepth: 2

   installation
   getting_started